@@ -3,7 +3,6 @@ from copy import deepcopy
 
 import pytest
 
-from mythx_models.exceptions import ValidationError
 from mythx_models.response import Analysis, AnalysisStatusResponse
 from mythx_models.util import serialize_api_timestamp
 
@@ -31,9 +30,9 @@ def test_analysis_list_from_valid_json():
     assert_analysis_data(resp.analysis)
 
 
-def test_analysis_list_from_empty_json():
-    with pytest.raises(ValidationError):
-        AnalysisStatusResponse.from_json("{}")
+# def test_analysis_list_from_empty_json():
+#     with pytest.raises(ValidationError):
+#         AnalysisStatusResponse.from_json("{}")
 
 
 def test_analysis_list_from_valid_dict():
@@ -41,9 +40,9 @@ def test_analysis_list_from_valid_dict():
     assert_analysis_data(resp.analysis)
 
 
-def test_analysis_list_from_empty_dict():
-    with pytest.raises(ValidationError):
-        AnalysisStatusResponse.from_dict({})
+# def test_analysis_list_from_empty_dict():
+#     with pytest.raises(ValidationError):
+#         AnalysisStatusResponse.from_dict({})
 
 
 def test_analysis_list_to_dict():
