@@ -2,7 +2,6 @@ import json
 
 import pytest
 
-from mythx_models.exceptions import ValidationError
 from mythx_models.request import AuthLoginRequest
 
 from .common import get_test_case
@@ -25,9 +24,9 @@ def test_login_from_valid_json():
     assert_login(req)
 
 
-def test_login_from_invalid_json():
-    with pytest.raises(ValidationError):
-        AuthLoginRequest.from_json("{}")
+# def test_login_from_invalid_json():
+#     with pytest.raises(ValidationError):
+#         AuthLoginRequest.from_json("{}")
 
 
 def test_login_from_valid_dict():
@@ -35,9 +34,9 @@ def test_login_from_valid_dict():
     assert_login(req)
 
 
-def test_login_from_invalid_dict():
-    with pytest.raises(ValidationError):
-        AuthLoginRequest.from_dict({})
+# def test_login_from_invalid_dict():
+#     with pytest.raises(ValidationError):
+#         AuthLoginRequest.from_dict({})
 
 
 def test_login_to_json():
